parse_assembly_report

Function parse_assembly_report 

pub fn parse_assembly_report<R>(
    id: GenomeBuildIdentifier,
    read: R,
) -> Result<GenomeBuild, GenomeAssemblyParseError>
where R: BufRead,
Parse an assembly report into a GenomeBuild.

The assembly report is expected to include a header lines that start with # and a tab-separated lines, one contig per line. Each contig line is expected to contain the following 10 fields:

  • Sequence-Name
  • Sequence-Role
  • Assigned-Molecule
  • Assigned-Molecule-Location/Type
  • GenBank-Accn
  • Relationship
  • RefSeq-Accn
  • Assembly-Unit
  • Sequence-Length
  • UCSC-style-name

Errors

The parsing can fail from the reasons outlined in GenomeAssemblyParseError.